Class: EndpointSecurity::File
- Inherits:
-
Object
- Object
- EndpointSecurity::File
- Defined in:
- lib/endpoint_security/object_model.rb
Overview
Lazy view of an es_file_t.
Instance Method Summary collapse
-
#path ⇒ String
Returns the possibly truncated path supplied by Endpoint Security.
Instance Method Details
#path ⇒ String
Returns the possibly truncated path supplied by Endpoint Security.
140 141 142 143 144 145 |
# File 'lib/endpoint_security/object_model.rb', line 140 def path if path_truncated? && __warn_on_truncated_path? warn "Endpoint Security path is truncated; do not use it for authorization" end __read_field("path") end |